@@ -21,7 +21,7 @@ insert_global_shims <- function() {
   e$`?` <- shim_question
   e$system.file <- shim_system.file
 
-  attach(e, name = "devtools_shims", warn.conflicts = FALSE)
+  base::attach(e, name = "devtools_shims", warn.conflicts = FALSE)
 }
 
 #' Replacement version of system.file
