@@ -20,10 +20,10 @@ rule <- function(..., pad = "-") {
   if (nargs() == 0) {
     title <- ""
   } else {
-    title <- paste0(...)
+    title <- paste0(..., " ")
   }
-  width <- getOption("width") - nchar(title) - 1
-  message(title, " ", paste(rep(pad, width, collapse = "")))
+  width <- max(getOption("width") - nchar(title) - 1, 0)
+  message(title, paste(rep(pad, width, collapse = "")))
 }
 
 # check whether the specified file ends with newline
@@ -46,6 +46,31 @@ is_installed <- function(pkg, version = 0) {
   !is.na(installed_version) && installed_version >= version
 }
 
+check_bioconductor <- function() {
+  if (is_installed("BiocInstaller")) {
+    return()
+  }
+
+  msg <- paste0("'BiocInstaller' must be installed to install Bioconductor packages")
+  if (!interactive()) {
+    stop(msg, call. = FALSE)
+  }
+
+  message(
+    msg, ".\n",
+    "Would you like to install it? ",
+    "This will source <https://bioconductor.org/biocLite.R>."
+  )
+
+  if (menu(c("Yes", "No")) != 1) {
+    stop("'BiocInstaller' not installed", call. = FALSE)
+  }
+
+  suppressMessages(
+    source("https://bioconductor.org/biocLite.R")
+  )
+}
+
 check_suggested <- function(pkg, version = NULL, compare = NA) {
 
   if (is.null(version)) {
@@ -236,3 +261,14 @@ strip_internal_calls <- function(x, package) {
     x
   }
 }
+
+sort_ci <- function(x) {
+  withr::with_collate("C", x[order(tolower(x), x)])
+}
+
+comma <- function(x, at_most = 20) {
+  if (length(x) > at_most) {
+    x <- c(x[seq_len(at_most)], "...")
+  }
+  paste(x, collapse = ", ")
+}
